@@ -1,7 +1,7 @@
 
 # Modulo "imprimeLista" que dispõe da função imprime que deverá imprimir Listas.
 
-def imprime(lista, level):
+def imprime(lista, level=0):
 
 # Função "imprime" que recebe qualquer tipo de lista reconhecida pelo python, e a quantidade de tabulação que deseja imprimir no argumento do parâmetro e imprime, caso haja listas aninhadas
 # é feito uso de recursividade para impressão.
